<?php
$lang['add'] = 'Lisa';
$lang['addcategory'] = 'Lisa kategooria';
$lang['addfielddef'] = 'Lisa v&auml;li';
$lang['adjustable'] = 'Muudetav';
$lang['addproduct'] = 'Lisa toode';
$lang['add_attrib_set'] = 'Lisa attribuut';
$lang['add_category_field'] = 'Seo v&auml;li kategooriaga: &quot;%s&quot;';
$lang['add_hierarchy_item'] = 'Lisa hierarhia element';
$lang['add_option'] = 'Lisa attribuudi valik';
$lang['admin_only'] = 'Kas ainult adminnid saavad n&auml;ha seda attribuuti?';
$lang['align_ul'] = '&Uuml;les vasakule';
$lang['align_uc'] = '&Uuml;les keskele';
$lang['align_ur'] = '&Uuml;les paremale';
$lang['align_ml'] = 'Vasakule keskele';
$lang['align_mc'] = 'Keskele';
$lang['align_mr'] = 'Paremale keskele';
$lang['align_ll'] = 'Alla vasakule';
$lang['align_lc'] = 'Alla keskele';
$lang['align_lr'] = 'Alla paremale';
$lang['allcategories'] = 'K&otilde;ik kategooriad';
$lang['areyousure'] = 'Oled sa kindel?';
$lang['areyousure_deleteproduct'] = 'Oled sa kindel, et soovid kustutada selle toote ja k&otilde;ik sellega seostuva informatsiooni?';
$lang['ascending'] = 'Kasvavalt';
$lang['attribute_name'] = 'Attribuudi nimi';
$lang['automatic'] = 'Automaatne';
$lang['byhierarchytemplates'] = 'Hierarchy Report Templates';
$lang['byhierarchytemplate_addedit'] = 'Add/Edit Hierarchy Report Template';
$lang['cancel'] = 'T&uuml;hista';
$lang['categories'] = 'Kategooriad';
$lang['category'] = 'Kategooria';
$lang['categoryexists'] = 'Sellise nimega kategooria eksisteerib juba';
$lang['categorylisttemplates'] = 'CategoryList Templates';
$lang['categorylisttemplate_addedit'] = 'Add/Edit A CategoryList Template';
$lang['checkbox'] = 'Checkbox';
$lang['confirm_delete_hierarchy_node'] = 'Oled sa kindel, et soovid kustutada selle elemendi? K&otilde;ik tooted, mis kasutavad seda elementi, seatakse puuduvaks hierarhiaks';
$lang['confirm_import'] = 'Oled sa kindel, et sa t&otilde;esti soovid seda teha?\n\nEbakorrektsed seaded v&otilde;i vale konfiguratsiooni fail v&otilde;ivad t&auml;iesti rikkuda praeguse toimiva s&uuml;steemi.';
$lang['copy'] = 'Kopeeri';
$lang['copy_category'] = 'Kopeeri kategooria';
$lang['createddate'] = 'Loodud';
$lang['current_value'] = 'Hetkev&auml;&auml;rtus';
$lang['data'] = 'Andmed';
$lang['default'] = 'Vaikimisi';
$lang['defaulttemplates'] = 'Vaikimisi mallid';
$lang['default_template_notice'] = '<strong>Note:</strong> The contents of these text areas are used to determine the default content of templates when you click &quot;Add Template&quot; in the appropriate template tab.  Editing one of these text areas will have no immediate effect on your website.';
$lang['delete'] = 'Kustuta';
$lang['delete_attribset'] = 'Kustuta attribuut';
$lang['delete_hierarchy_item'] = 'Kustuta hierarhia element';
$lang['descending'] = 'Kahanevalt';
$lang['description'] = 'Kirjeldus';
$lang['details'] = 'Detailid';
$lang['detailtemplates'] = 'Detailide mall';
$lang['detailtemplate_addedit'] = 'Lisa/Muuda detailide mall';
$lang['disabled'] = 'Disabled';
$lang['draft'] = 'Mustand';
$lang['dropdown'] = 'Dropdown';
$lang['dropdown_options'] = 'Dropdown Options <em>(applicable only for dropdown fields)</em><br/><br/><em>(one entry per line)</em>';
$lang['edit'] = 'Muuda';
$lang['edit_attribset'] = 'Muuda attribuuti';
$lang['edit_attribsets'] = 'Muuda attribuudi seadeid';
$lang['edit_attribsets_for'] = 'Edit Attribute Sets For';
$lang['edit_attributes'] = 'Muuda attribuute';
$lang['edit_category'] = 'Muuda kategooriat';
$lang['edit_category_fields'] = 'Muuda kategooria v&auml;lju';
$lang['edit_hierarchy_item'] = 'Muuda hierarhia elementi';
$lang['error_attribset_exists'] = 'Sellise nimega attribuut on juba olemas';
$lang['error_fieldvalue_empty'] = 'V&auml;lja v&auml;&auml;rtus ei saa olla t&uuml;hi';
$lang['error_fileformat'] = 'Faili formaadi probleem';
$lang['error_filenotfound'] = 'Faili ei leitud';
$lang['error_fileopen'] = 'Probleem faili %s avamisel';
$lang['error_invalidparent'] = 'Vale vanem (hierarhia element ei saa olla iseenda vanem)';
$lang['error_invalid_name'] = 'The custom field value entered is invalid (contains non alphanumeric characters)';
$lang['error_missingparam'] = 'A required parameter is missing or invalid';
$lang['error_nameused'] = 'An item by that name is already in use';
$lang['error_nofieldtype'] = 'Please select a field type';
$lang['error_noname'] = 'You must supply a name';
$lang['error_permissiondenied'] = 'Permission Denied';
$lang['error_product_nameused'] = 'Sellise nime toode on juba olemas';
$lang['error_price_adjustment'] = 'Vale hinna muudatuse v&auml;&auml;rtus elemendile %s';
$lang['error_upload_failed'] = '&Uuml;leslaadimine eba&otilde;nnestus: %s';
$lang['extra1'] = 'Ekstra v&auml;li 1';
$lang['extra2'] = 'Ekstra v&auml;li 2';
$lang['field'] = 'V&auml;li';
$lang['fielddef'] = 'V&auml;lja definitsioon';
$lang['fielddefs'] = 'V&auml;lja definitsioonid';
$lang['file'] = 'Fail';
$lang['filters'] = 'Filtrid';
$lang['firstpage'] = '<<';
$lang['general_settings'] = 'Peamised seaded';
$lang['go'] = 'Mine';
$lang['hierarchy'] = 'Hierarhia';
$lang['hierarchy_position'] = 'Hierarhia positsioon';
$lang['id'] = 'Id';
$lang['imagetext'] = 'Pilt';
$lang['image_handling_settings'] = 'Pildi k&auml;itlemise seaded';
$lang['import_from_csv'] = 'Import Products from CSV file';
$lang['include_children'] = 'Include Children?';
$lang['info_alnumonly'] = 'Only alphanumeric characters. No whitespace, quotes, or non letter/number combinations';
$lang['info_autowatermark'] = 'Watermark settings are taken from the CGExtensions Module';
$lang['info_batchsize'] = 'Set the number of lines to process per &quot;batch&quot;.  After a batch is complete, the importer will redirect, and resume operations.  If you are experiencing memory errors, or timeout problems due to large amounts of processing, you may need to consult your host provider, or reduce this number';
$lang['info_cart_module_params'] = 'These parameters are given to the selected cart module from the product detail and summary displays';
$lang['info_createfields'] = 'Create unknown product fields automatically? <em>(They will be created as text fields)</em>';
$lang['info_createcategories'] = 'Automatically create product categories to match those of the CSV file, if it does not already exist';
$lang['info_createhierarchy'] = 'Automatically create product hierarchies to match those of the CSV file if it does not already exist';
$lang['info_decimal_units'] = 'This system understands (.) as the decimal point separator. i.e.: <strong>5.25</strong>';
$lang['info_delimiter'] = 'Specify the character (or characters) that seperate each field';
$lang['info_duplicateproducts'] = 'Specify how the system should handle a product whos name already exists in the CSV file';
$lang['info_fielddefs_tab'] = '<strong>Note: </strong> All Fields defined here are available to all products.';
$lang['info_fieldproblems'] = 'Problems were encountered when dealing with one or more custom fields.  The action has completed successfully, however you should investigate and correct these problems';
$lang['info_handleimages'] = 'Upon import, if an image filename is found in a field column, should it be moved from the source location, watermarked, thumbnailed, and the field type changed to &quot;image&quot;';
$lang['info_imagepath'] = 'The path (relative to the uploads directory) where images referred to in the import file, can be found';
$lang['info_import_test_passed'] = 'A brief test as been performed on the input file specified, and everything appears to be correct.<br/>This is no indication that there are no errors in the file.';
$lang['info_price_adjustment'] = 'Valid values are +-*#.##';
$lang['info_publicfield'] = 'Public fields are available for the public to see';
$lang['label'] = 'Label';
$lang['label_skip'] = 'Skip';
$lang['label_overwrite'] = 'Overwrite';
$lang['lastpage'] = '>>';
$lang['last_modified'] = 'Viimati muudetud';
$lang['logotext'] = 'Teine pilt';
$lang['maxlength'] = 'Maximum length <em>(applicable only on textbox fields)</em>';
$lang['modifieddate'] = 'muudetud';
$lang['module_description'] = 'A module for managing a catalog of products, their price, images, etc, and for allowing users to build a cart';
$lang['name'] = 'Nimi';
$lang['needpermission'] = 'You do not have the required permission: %s';
$lang['new_category_name'] = 'Uus kategooria nimi';
$lang['nextpage'] = '>';
$lang['no'] = 'Ei';
$lang['nonamegiven'] = 'Nime ei esitatud';
$lang['none'] = 'Pole';
$lang['of'] = 'kokku';
$lang['page'] = 'Lehek&uuml;lg';
$lang['page_of'] = 'Lehek&uuml;lg %s %s&#039;st';
$lang['page_limit'] = 'Lehek&uuml;lje limiit';
$lang['param_action'] = 'Specify the behaviour of the module.  Possible values are:
<ul>
  <li>hierarchy -- Display a product list by hierarchy</li>
  <li>categorylist - Display a list of product categories</li>
  <li><em>default</em> - Display a summary of products</li>
  <li>details - Display a detail view of a single product</li>
</ul>';
$lang['param_category'] = 'When used in the <em>default</em> summary mode, this parameter, which should match the name of an existing category will be used to display only those products that are in that categoory. (a comma seperated list can be supplied)';
$lang['param_categorylisttemplate'] = 'Useful only with the categorylist action, this parameter indicates the template that should be used for the display.  If no value is specified then the current default template of that type is used.';
$lang['param_detailpage'] = 'This specifies the pageid or alias that should be used to display the detail report.';
$lang['param_detailtemplate'] = 'This parameter specifies the template that should be used for the detail mode display.  If no value is specified, then the current default template of that type is used.';
$lang['param_hierarchy'] = 'Useful only in the <em>default</em> action, this parameter specifies that only items in that location of the hierarchy should be displayed.  Wildcard character can be used so that you can specify parent/child relationships as well.  i.e {Products hierarchy=&#039;trucks*&#039;} will create a summary report of all trucks, including the children in the hierarchy.  Similarly, {Products hierarchy=&#039;*trucks&#039;} will display a summary report of all trucks, and all products beloging to any parent in the hierarchy.';
$lang['param_hierarchytemplate'] = 'This parameter specifies the template that should be used for the hierarchy display. If no value is specified, then the current default template of that type is used.';
$lang['param_pagelimit'] = 'Useful only with the <em>default</em> action, this parameter specifies how many items should be listed on each page.';
$lang['param_parent'] = 'Useful only in the <em>hierarchy</em> action, this parameter specifies the hierarchy id of the starting location of the report.';
$lang['param_productid'] = 'Useful only with the detail action, this parameter indicates what product to use for the display.';
$lang['param_sortorder'] = 'Specify the order of sorted fields in summary view.  Possible values are:
<ul>
  <li><strong>asc</strong> -- Ascending order</li>
  <li>desc -- Descending order</li>
</ul>';
$lang['param_sortby'] = 'Applicable only in summary mode, this parameter determines the sorting of the output products.  Possible values are:
<ul>
  <li><strong>product_name</strong></li>
  <li>id -- The product id</li>
  <li>weight -- The product weight</li>
  <li>price -- The product base price</li>
  <li>status -- Draft or published</li>
  <li>random -- Display in random order on each request</li>
  <li>created -- The creation date for this company record</li>
  <li>modified -- The modified date for this company record</li>
</ul>';
$lang['param_summarytemplate'] = 'This parameter specifies the template that should be used for the summary mode display.  If no value is specified, then the current default template of that type is used.';
$lang['parent'] = 'Eelmine';
$lang['postinstall'] = 'Toodete moodul on edukalt paigaldatud';
$lang['postuninstall'] = 'Toodete moodul on eemldatud koos k&otilde;ikide seotud andmetega';
$lang['preferences'] = 'Eelistused';
$lang['preuninstall'] = 'Selle mooduli eemaldamine eemaldab ka k&otilde;ik seotud andmed, oled sa kindel, et soovid j&auml;tkata?';
$lang['price'] = 'Hind';
$lang['price_adjustment'] = 'Hinna muudatus';
$lang['prevpage'] = '<';
$lang['product'] = 'Toode';
$lang['productname'] = 'Toote nimi';
$lang['products'] = 'Tooted';
$lang['product_hierarchy'] = 'Toote hierarhia';
$lang['product_manager'] = 'Toote haldur';
$lang['progress'] = 'Progress';
$lang['prompt'] = 'Prompt';
$lang['prompt_allowed_filetypes'] = 'Allow upload of files with these extensions (for file type fields)';
$lang['prompt_allowed_imagetypes'] = 'Allow upload of images with these extensions (for image type fields)';
$lang['prompt_autothumbnail'] = 'Automatically create thumbnails of images';
$lang['prompt_autothumbnail_size'] = 'Maximum size (largest dimension) of the thumbnail.';
$lang['prompt_autopreviewimg'] = 'Automatically create preview images of images';
$lang['prompt_autopreviewimg_size'] = 'Maximum size (largest dimension) of the preview image.';
$lang['prompt_autowatermark'] = 'Automatically place watermarks on images';
$lang['prompt_applicable'] = 'Enable by default for all new products';
$lang['prompt_batchsize'] = 'Batch Size';
$lang['prompt_cart_module'] = 'Cart Module';
$lang['prompt_cart_module_params'] = 'Cart Module Parameters';
$lang['prompt_createcategories'] = 'Loo kategooriaid';
$lang['prompt_createfields'] = 'Loo toote v&auml;ljasid?';
$lang['prompt_createhierarchy'] = 'Loo toote hierarhia';
$lang['prompt_csvfile'] = 'Upload CSV File';
$lang['prompt_currencycode'] = 'Valuuta kood';
$lang['prompt_currencysymbol'] = 'Valuuta s&uuml;mbol';
$lang['prompt_default_status'] = 'Vaikimisi k&otilde;ikidel uutel toodetel on see olek';
$lang['prompt_default_taxable'] = 'Vaikimisi k&otilde;ik uued tooted on maksustavad';
$lang['prompt_deleteproductfiles'] = 'Kustuta k&otilde;ik tootega seotud failid, kui toode kustutatakse?';
$lang['prompt_delimiter'] = 'V&auml;lja eraldaja';
$lang['prompt_detailpage'] = 'Vaikimisi detaili leht';
$lang['prompt_duplicateproducts'] = 'How to handle duplicate products?';
$lang['prompt_handleimages'] = 'Handle images?';
$lang['prompt_imagepath'] = 'Image Path';
$lang['prompt_summarysortorder'] = 'Default Sort Order in summary mode';
$lang['prompt_summarysorting'] = 'Default Sort Field in summary mode';
$lang['prompt_template'] = 'Template Source';
$lang['prompt_urlprefix'] = 'Prefix to use on all URLS targeted to this this module';
$lang['prompt_weightunits'] = 'Kaalu &uuml;hikud';
$lang['public'] = 'Kas see on avalik v&auml;li??';
$lang['published'] = 'Avaldatud';
$lang['random'] = 'Suvaline';
$lang['resettofactory'] = 'Taasta tehase v&auml;&auml;rtused';
$lang['return'] = 'Tagasi';
$lang['return_to_top'] = 'Tagasi vaate tippu';
$lang['root'] = 'Juur';
$lang['select_one'] = 'Vali &uuml;ks';
$lang['sort_by'] = 'Sorteeri';
$lang['sort_order'] = 'Sorteeri j&auml;rjekord';
$lang['status'] = 'Olek';
$lang['submit'] = 'Saada';
$lang['summarytemplates'] = 'Kokkuv&otilde;tte mall';
$lang['summarytemplate_addedit'] = 'Lisa/Muuda kokkuv&otilde;tte mall';
$lang['taxable'] = 'Maksustatav';
$lang['test'] = 'Test';
$lang['textarea'] = 'Text Area';
$lang['textbox'] = 'Text Input';
$lang['title_byhierarchy_dflttemplate'] = 'Default New Hierarchy Report Template';
$lang['title_categorylist_dflttemplate'] = 'Default New CategoryList Template';
$lang['title_detail_dflttemplate'] = 'Default New Detail Template';
$lang['title_summary_dflttemplate'] = 'Default New Summary Template';
$lang['type'] = 'T&uuml;&uuml;p';
$lang['update'] = 'Uuenda';
$lang['upload'] = 'Vali fail &uuml;leslaadimiseks';
$lang['valid'] = 'Kehtiv';
$lang['value'] = 'V&auml;&auml;rtus';
$lang['values'] = 'V&auml;&auml;rtused';
$lang['watermark_location'] = 'Vesipildi asukoht';
$lang['weight'] = 'Kaal';
$lang['yes'] = 'Jah';
$lang['utma'] = '156861353.3215545266732019000.1241091787.1255528330.1255602290.165';
$lang['utmz'] = '156861353.1254469083.145.28.utmccn=(organic)|utmcsr=google|utmctr=cmsms requirements|utmcmd=organic';
$lang['qca'] = '1240683615-58409973-79915303';
$lang['utmb'] = '156861353.1.10.1255602290';
$lang['utmc'] = '156861353';
?>
